@@ -12,14 +12,14 @@ pub(crate) fn all(x: F64X2) -> bool {
     unsafe { transmute::<_, u64>(vmovn_u64(transmute(x))) == !0u64 }
 }
 
-pub(crate) fn any(x: F64X2) -> bool {
-    unsafe { transmute::<_, u64>(vmovn_u64(transmute(x))) != 0u64 }
-}
-
 pub(crate) fn and(x: F64X2, y: F64X2) -> F64X2 {
     unsafe { transmute(vandq_u64(transmute(x), transmute(y))) }
 }
 
+pub(crate) fn any(x: F64X2) -> bool {
+    unsafe { transmute::<_, u64>(vmovn_u64(transmute(x))) != 0u64 }
+}
+
 pub(crate) fn bitmask(x: F64X2) -> u32 {
     let [a, b] = unsafe { transmute::<_, [u64; 2]>(x) };
     (b as u32) & 0x2 | (a as u32) & 0x1
@@ -109,10 +109,6 @@ pub(crate) fn shuffle03(x: F64X2, y: F64X2) -> F64X2 {
     constant(extract0(x), extract1(y))
 }
 
-pub(crate) fn shuffle12(x: F64X2, y: F64X2) -> F64X2 {
-    constant(extract1(x), extract0(y))
-}
-
 pub(crate) fn shuffle13(x: F64X2, y: F64X2) -> F64X2 {
     constant(extract1(x), extract1(y))
 }
@@ -129,6 +125,10 @@ pub(crate) fn trunc(x: F64X2) -> F64X2 {
     vrndq_f64(x)
 }
 
+fn shuffle12(x: F64X2, y: F64X2) -> F64X2 {
+    constant(extract1(x), extract0(y))
+}
+
 macro_rules! impl_op {
     ($t:ty, $f:ident ($x:ident $(,$y:ident)*), $inst:literal) => {
         pub(crate) fn $f(mut $x: $t, $($y: $t,)*) -> $t {
